import os
import stripe

from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from .endpoints import (
    carbon,
    diversity,
    checkouts,
    goalsprojects,
    emails,
    funds,
    subs,
    company,
    customs,
    renewal_impact,
    cbiv_impact,
    measurements,
    files
)
from .configs.config import (
    Settings,
    stripe_key,
    sendgrid_email,
    sendgrid_id,
    sendgrid_id2,
    sendgrid_id3,
    sendgrid_id4,
    sendgrid_key,
)

stripe.api_key = stripe_key

HOST = Settings["host"]
MASTER_KEY = Settings["master_key"]
DATABASE_ID = Settings["database_id"]
CONTAINER_ID = Settings["container_id"]
CONTAINER_ID2 = Settings["container_id2"]
CONTAINER_ID3 = Settings["container_id3"]
CONTAINER_ID4 = Settings["container_id4"]
CONTAINER_ID5 = Settings["container_id5"]
CONTAINER_ID6 = Settings["container_id6"]
CONTAINER_ID7 = Settings["container_id7"]
CONTAINER_ID8 = Settings["container_id8"]
CONTAINER_ID9 = Settings["container_id9"]
CONTAINER_ID10 = Settings["container_id10"]
CONTAINER_ID11 = Settings["container_id11"]
CONTAINER_ID12 = Settings["container_id12"]
FROM_EMAIL = sendgrid_email
TEMPLATE_ID = sendgrid_id
TEMPLATE_ID2 = sendgrid_id2
TEMPLATE_ID3 = sendgrid_id3
TEMPLATE_ID4 = sendgrid_id4
SENDGRID_API_KEY = sendgrid_key


app = FastAPI(docs_url=None, redoc_url=None)
app.include_router(carbon.carbonroute, prefix="/carbon")
app.include_router(diversity.diversityroute, prefix="/diversity")
app.include_router(checkouts.checkoutroute, prefix="/checkout")
app.include_router(goalsprojects.goalprojectroute, prefix="/goalsprojects")
app.include_router(emails.emailroute, prefix="/emails")
app.include_router(funds.fundroute, prefix="/funds")
app.include_router(subs.subroute, prefix="/subs")
app.include_router(company.companyroute, prefix="/company")
app.include_router(customs.customsroute, prefix="/customs")

# renewal impact management
app.include_router(renewal_impact.router, prefix="/impact-management")

# cbiv impact management
app.include_router(cbiv_impact.router, prefix="/cbiv")

# measurements api routes
app.include_router(measurements.router, prefix="/measurements")

# files routes
app.include_router(files.router, prefix="/files")


NODE_DEV = os.getenv("NODE_DEV")

if NODE_DEV == "production":
    MY_DOMAIN = "https://metricplatformapi.com/"

    origins = ["https://www.metric-platform.com/", "https://metric-platform.com/"]
elif NODE_DEV == "test":
    MY_DOMAIN = "https://metricplatform-staging.azurewebsites.net/"

    origins = [
        "https://www.metricplatform-info-metric-esgc-metric-dev.vercel.app/",
        "https://metricplatform-info-metric-esgc-metric-dev.vercel.app/",
    ]
else:
    MY_DOMAIN = "http://localhost:8000/"

    origins = ["http://localhost:3000", "localhost:3000/"]


app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)
